@@ -16,7 +16,7 @@ EMBER_BLUETOOTH_NAMES: tuple[str, ...] = ("Ember Ceramic Mug",)
 UUID_MUG_NAME = UUID("fc540001-236c-4c94-8fa9-944a3e5353fa")
 
 # Current Mug Temp (Read)
-UUID_DRINK_TEMPERATURE = UUID("fc540002-236c-4c94-8fa9-944a3e5353fa")
+UUID_CURRENT_TEMPERATURE = UUID("fc540002-236c-4c94-8fa9-944a3e5353fa")
 
 # Target Mug Temp (Read/Write)
 UUID_TARGET_TEMPERATURE = UUID("fc540003-236c-4c94-8fa9-944a3e5353fa")
